SignInWithPhoneUseCase class
- Inheritance
-
- Object
- ISignInWithPhoneUseCase
- SignInWithPhoneUseCase
Constructors
- SignInWithPhoneUseCase({required IExaAuthDatasource exaAuthDatasource, required IUserStreamUseCase streamUseCase})
Properties
- exaAuthDatasource → IExaAuthDatasource
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamUseCase → IUserStreamUseCase
-
final
Methods
-
call(
{required String phoneNumber, required dynamic verificationCompleted(ExaAuthUser p1), required dynamic verificationFail(AuthFailure p1), required dynamic codeSent(String? p1, int? p2), int? seconds, int? forceResendingToken}) → Future< void> -
override
-
callSms(
{required String verificationId, required String smsToken}) → Future< Either< AuthFailure, ExaAuthUser?> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited